==> tuia-treasure-center-api-0.0.1.zwb8-20180424.041909-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/StickContentDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;


import java.io.Serializable;

/**
 * Created by zhou_wb on 2018/4/23.
 */
public class StickContentDto implements Serializable{


    private static final long serialVersionUID = 1260424276929123087L;

    /**
     * id
     */
    private Long id;
    /**
     * 内容标题
     */
    private  String title;


    /**
     * 内容链接地址
     */
    private String url;


    /**
     * 缩略图地址
     */
    private String  imageUrl;

    /**
     * 内容排序
     */
    private Integer sort;


    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 评论数
     */
    private Long commentNumber;




    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public String getMediaName() {
        return mediaName;
    }

    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCommentNumber() {
        return commentNumber;
    }

    public void setCommentNumber(Long commentNumber) {
        this.commentNumber = commentNumber;
    }
}

==> tuia-treasure-center-api-0.0.6.zwb16-20180606.151650-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/StickContentDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;


import java.io.Serializable;
import java.util.Date;

/**
 * Created by zhou_wb on 2018/4/23.
 */
public class StickContentDto implements Serializable{


    private static final long serialVersionUID = 1260424276929123087L;

    /**
     * id
     */
    private Long id;
    /**
     * 内容标题
     */
    private  String title;


    /**
     * 内容链接地址
     */
    private String url;


    /**
     * 缩略图地址
     */
    private String  imageUrl;

    /**
     * 内容排序
     */
    private Integer sort;


    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 评论数
     */
    private Long commentNumber;

    /**
     * 发布日期
     * @return
     */
    private Date gmtCreate;

    /**
     * 是否已删除
     * @return
     */
    private Integer isDelete;


    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public String getMediaName() {
        return mediaName;
    }

    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCommentNumber() {
        return commentNumber;
    }

    public void setCommentNumber(Long commentNumber) {
        this.commentNumber = commentNumber;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Integer getIsDelete() {
        return isDelete;
    }

    public void setIsDelete(Integer isDelete) {
        this.isDelete = isDelete;
    }
}
